* {
  border-radius: 0;
  border: none;
  text-shadow: 1px 1px 3px rgba(0, 0, 0, 0.7)
}

button {
  background: none;
  padding: 10px
}

#clock-label {
  font-family: monospace
}

#unlock-button {
  border: 1px solid #000;
  background-color: rgba(37, 37, 37, 0.95)
}

#powerbar-box {
  border: 1px solid #000;
  background-color: rgba(37, 37, 37, 0.95)
}

#input-field {
  border: 1px solid #000;
  background-color: rgba(37, 37, 37, 0.95)
}

#playerctl-box {
  border: 1px solid #000;
  margin: 20px;
  background-color: rgba(37, 37, 37, 0.8)
}